# Changelog

## [2.4.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.4.0a1) (2024-11-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.3.2...2.4.0a1)

**Merged pull requests:**

- feat:skilljson and homescreen [\#283](https://github.com/OpenVoiceOS/OVOS-workshop/pull/283) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
